'use strict';

class HtmlJsonBlock {
	static Font = 'Arial';
	static Colors = {
		SquareBracket: "#FF1493",
		Key: "#008B8B",
		Colon: "#FF1493",
		String: "#DC143C",
		Number: "#32CD32",
		Boolean: "#DAA520",
		Null: "#8B4513",
		Object: "#556B2F",
		Array: "#7B68EE"
	}

	constructor(body) {
		this.index = 1;
		this.raw = body;
		this.newBody = [
			'{<br />'
		];

		Object.keys(body).forEach((value, index, arr) => {
			const subValue = Object.values(body);
			if(index === arr.length - 1) {
				this.newBody.push(`${HtmlJsonBlock.space(2)}${HtmlJsonBlock.font(HtmlJsonBlock.Colors.Key, `"${value}"`)}: ${HtmlJsonBlock.valueColor(subValue[index])}`);
			} else {
				this.newBody.push(`${HtmlJsonBlock.space(2)}${HtmlJsonBlock.font(HtmlJsonBlock.Colors.Key, `"${value}"`)}: ${HtmlJsonBlock.valueColor(subValue[index])}${HtmlJsonBlock.font(HtmlJsonBlock.Colors.Colon, ',')}<br />`);
			}
		});
		this.newBody.push('<br />}');
		this.body.bind(this);
	}

	static color(color, value, type) {
		switch(type) {
			case 'String':
				return HtmlJsonBlock.font(color, `"${value}"`);
			break;
	
			case 'Number':
				return HtmlJsonBlock.font(color, value)
			break;
			
			case 'Boolean':
				return HtmlJsonBlock.font(color, value)
			break;
			
			case 'Null':
				return HtmlJsonBlock.font(color, value)
			break;
			
			case 'Object':
				this.subObject = (new HtmlJsonBlock(value)).subBody();
				this.subObject = this.subObject.substring(1, this.subObject.length - 1)
				return `${HtmlJsonBlock.font(HtmlJsonBlock.Colors.Object, '{')}${HtmlJsonBlock.font(color, HtmlJsonBlock.subObject.replaceAll(HtmlJsonBlock.space(2), `${HtmlJsonBlock.space(3)}#p$l$a$c$-$lZi:MUl$`))}${HtmlJsonBlock.font(HtmlJsonBlock.Colors.Object, `${HtmlJsonBlock.space(2)}}`)}`;
			break;

			case 'Array':
				return [HtmlJsonBlock.font(HtmlJsonBlock.Colors.Array, '['), value.map(value => HtmlJsonBlock.font(color, HtmlJsonBlock.valueColor(value))).join(', '), HtmlJsonBlock.font(HtmlJsonBlock.Colors.Array, ']')].join('')
			break;
		}
	}

	static valueColor(value) {
		switch(Object.prototype.toString.call(value)) {
			case '[object String]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.String, value, 'String');
			break;

			case '[object Number]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.Number, value, 'Number');
			break;

			case '[object Boolean]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.Boolean, value, 'Boolean');
			break;
			
			case '[object Null]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.Null, value, 'Null');
			break;

			case '[object Object]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.Object, value, 'Object');
			break;

			case '[object Array]':
				return HtmlJsonBlock.color(HtmlJsonBlock.Colors.Array, value, 'Array');
			break;
		}
	}
	
	static font(color, content) {
		return `<font style="color: ${color}; font-family: ${HtmlJsonBlock.Font}">${content}</font>`;
	}
	
	static space(quantity) {
		return new Array(quantity).fill('&nbsp;').join('');
	}
	
	subBody() {
		return this.newBody.join('');
	}
	
	body(status) {
		if(status)
		return this.raw;
		else
		return this.newBody.join('').replaceAll('#p$l$a$c$-$lZi:MUl$', HtmlJsonBlock.space(1));
	}
};

export default HtmlJsonBlock;